/******************************************************************************
*                                                                             *
*                            Module specification                             *
*                                                                             *
*                                Copyright by                                 *
*                                                                             *
*                              Azoteq (Pty) Ltd                               *
*                          Republic of South Africa                           *
*                                                                             *
*                           Tel: +27(0)21 863 0033                            *
*                          E-mail: info@azoteq.com                            *
*                                                                             *
*******************************************************************************
Name             :  main.c
Description      :  IQS316 specific functions for I2C Firmware library
*******************************************************************************/


/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      revision   :  IQS316 I2C Firmware library rev 1.01
          date   :  2013-12-03
            by   :  Robert Samuel
   description   :  Basic functions to implement IQS316 via I2C (PIC18F4550 was used)
 */
#include "includes.h"

/*
********************************************************************************
*		Pragma Section
*
* Configuration bits under MPLAB v7.41 subject to changes on every little change on project settings.
* So #pragma config statments used for configuration bits instead of using Configuration bits tab in MPLAB
* Note: Refer to pdf document "mcc18\doc\MPLAB-C18-Addendum.pdf" under mcc18 installation directory for config
* 		variables available
********************************************************************************
*/

//
// MCU configuration settings
//
#pragma config PLLDIV   = 2             
#pragma config CPUDIV   = OSC1_PLL2     
#pragma config USBDIV   = 2            
#pragma config FOSC     = HSPLL_HS
#pragma config FCMEN    = OFF
#pragma config IESO     = OFF
#pragma config PWRT     = OFF
#pragma config BOR      = ON
#pragma config BORV     = 3
#pragma config WDT      = OFF
#pragma config WDTPS    = 32768
#pragma config MCLRE    = ON
#pragma config LPT1OSC  = OFF
#pragma config PBADEN   = OFF
#pragma config STVREN   = ON
#pragma config LVP      = OFF
#pragma config XINST    = OFF
#pragma config CP0      = OFF
#pragma config CP1      = OFF
#pragma config CPB      = OFF
#pragma config WRT0     = OFF
#pragma config WRT1     = OFF
#pragma config WRTB     = OFF
#pragma config WRTC     = OFF
#pragma config EBTR0    = OFF
#pragma config EBTR1    = OFF
#pragma config EBTRB    = OFF

//*****************************************************************************
//
//! Main Function
//!
//! Initialise the device, then continually read data from the IQS316, and 
//! then process this data
//!
//! \param None
//!
//! \return None
//
//*****************************************************************************
void
main(void)
{
    init();

    while(1)
    {
        // Get data from latest comms window
        //
        IQS316_Refresh_Data();
        //
        // Process this new data accordingly
        //
        IQS316_Process_Data();
    }
}

